package com.hw.dms.service;

import java.util.List;
import com.hw.dms.domain.DmsBaseTransferInfo;

/**
 * 设备转移信息Service接口
 * 
 * @author xins
 * @date 2024-01-02
 */
public interface IDmsBaseTransferInfoService 
{
    /**
     * 查询设备转移信息
     * 
     * @param transferInfoId 设备转移信息主键
     * @return 设备转移信息
     */
    public DmsBaseTransferInfo selectDmsBaseTransferInfoByTransferInfoId(Long transferInfoId);

    /**
     * 查询设备转移信息列表
     * 
     * @param dmsBaseTransferInfo 设备转移信息
     * @return 设备转移信息集合
     */
    public List<DmsBaseTransferInfo> selectDmsBaseTransferInfoList(DmsBaseTransferInfo dmsBaseTransferInfo);

    /**
     * 新增设备转移信息
     * 
     * @param dmsBaseTransferInfo 设备转移信息
     * @return 结果
     */
    public int insertDmsBaseTransferInfo(DmsBaseTransferInfo dmsBaseTransferInfo);

    /**
     * 修改设备转移信息
     * 
     * @param dmsBaseTransferInfo 设备转移信息
     * @return 结果
     */
    public int updateDmsBaseTransferInfo(DmsBaseTransferInfo dmsBaseTransferInfo);

    /**
     * 批量删除设备转移信息
     * 
     * @param transferInfoIds 需要删除的设备转移信息主键集合
     * @return 结果
     */
    public int deleteDmsBaseTransferInfoByTransferInfoIds(Long[] transferInfoIds);

    /**
     * 删除设备转移信息信息
     * 
     * @param transferInfoId 设备转移信息主键
     * @return 结果
     */
    public int deleteDmsBaseTransferInfoByTransferInfoId(Long transferInfoId);
}
